@@ -1,5 +1,6 @@
 from . import mixins
 from .HowFairIsChecker import HowFairIsChecker
+from .__version__ import __version__
 
 
 __author__ = "https://github.com/jspaaks"
@@ -7,5 +8,6 @@ __email__ = 'j.spaaks@esciencecenter.nl'
 
 __all__ = [
     "HowFairIsChecker",
-    "mixins"
+    "mixins",
+    "__version__"
 ]
