@@ -4,6 +4,15 @@ import requests
 class CitationMixin:
 
     def check_citation(self):
+        force = self.config.get("force", dict())
+        if not isinstance(force, dict):
+            force = dict()
+        force_state = force.get("citation")
+        if force_state not in [True, False, None]:
+            raise ValueError("Unexpected configuration value for force.citation.")
+        if isinstance(force_state, bool):
+            print("(4/5) citation: force {0}".format(force_state))
+            return force_state
         print("(4/5) citation")
         results = [
             self.has_citation_file(),
@@ -16,15 +25,15 @@ class CitationMixin:
 
     def has_citation_file(self):
         url = "https://raw.githubusercontent.com/" + \
-              "{0}/{1}/{2}/CITATION".format(self.owner, self.repo, self.branch)
+              "{0}/{1}/{2}/{3}/CITATION".format(self.owner, self.repo, self.branch, self.path)
         try:
             response = requests.get(url)
             # If the response was successful, no Exception will be raised
             response.raise_for_status()
         except requests.HTTPError:
-            self.print_state(check_name="has_citation_file", state=False)
+            self._print_state(check_name="has_citation_file", state=False)
             return False
-        self.print_state(check_name="has_citation_file", state=True)
+        self._print_state(check_name="has_citation_file", state=True)
         return True
 
     def has_citationcff_file(self):
@@ -35,9 +44,9 @@ class CitationMixin:
             # If the response was successful, no Exception will be raised
             response.raise_for_status()
         except requests.HTTPError:
-            self.print_state(check_name="has_citationcff_file", state=False)
+            self._print_state(check_name="has_citationcff_file", state=False)
             return False
-        self.print_state(check_name="has_citationcff_file", state=True)
+        self._print_state(check_name="has_citationcff_file", state=True)
         return True
 
     def has_codemeta_file(self):
@@ -48,9 +57,9 @@ class CitationMixin:
             # If the response was successful, no Exception will be raised
             response.raise_for_status()
         except requests.HTTPError:
-            self.print_state(check_name="has_codemeta_file", state=False)
+            self._print_state(check_name="has_codemeta_file", state=False)
             return False
-        self.print_state(check_name="has_codemeta_file", state=True)
+        self._print_state(check_name="has_codemeta_file", state=True)
         return True
 
     def has_zenodo_badge(self):
@@ -66,7 +75,7 @@ class CitationMixin:
             # If the response was successful, no Exception will be raised
             response.raise_for_status()
         except requests.HTTPError:
-            self.print_state(check_name="has_zenodo_metadata_file", state=False)
+            self._print_state(check_name="has_zenodo_metadata_file", state=False)
             return False
-        self.print_state(check_name="has_zenodo_metadata_file", state=True)
+        self._print_state(check_name="has_zenodo_metadata_file", state=True)
         return True
