@@ -4,8 +4,18 @@ import requests
 class RegistryMixin:
 
     def check_registry(self):
+        force = self.config.get("force", dict())
+        if not isinstance(force, dict):
+            force = dict()
+        force_state = force.get("registry")
+        if force_state not in [True, False, None]:
+            raise ValueError("Unexpected configuration value for force.registry.")
+        if isinstance(force_state, bool):
+            print("(3/5) registry: force {0}".format(force_state))
+            return force_state
         print("(3/5) registry")
         results = [
+            self.has_ascl_badge(),
             self.has_bintray_badge(),
             self.has_conda_badge(),
             self.has_cran_badge(),
@@ -18,6 +28,10 @@ class RegistryMixin:
         ]
         return True in results
 
+    def has_ascl_badge(self):
+        regexes = [r"https://img\.shields\.io/badge/ascl.*"]
+        return self._eval_regexes(regexes)
+
     def has_bintray_badge(self):
         regexes = [r"https://api\.bintray\.com/packages/.*/.*/.*/images/download\.svg",
                    r"https://img\.shields\.io/bintray/.*"]
@@ -69,11 +83,11 @@ class RegistryMixin:
             # If the response was successful, no Exception will be raised
             response.raise_for_status()
         except requests.HTTPError:
-            self.print_state(check_name="is_on_github_marketplace", state=False)
+            self._print_state(check_name="is_on_github_marketplace", state=False)
             return False
 
         html = response.text
         r = "Use this GitHub Action with your project" in html and \
             "Add this Action to an existing workflow or create a new one." in html
-        self.print_state(check_name="is_on_github_marketplace", state=r)
+        self._print_state(check_name="is_on_github_marketplace", state=r)
         return r
